@@ -27,14 +27,13 @@ Commands:
   outdated             displays all outdated software
   upgrade target       installs upgraded target software
   rehash target        re-create target software's symbolic link
-  freeze               displays configuration file reproduce installed software
+  freeze               displays a conditions script reproduce installed software
   deploy ~/path        deploys all installed software to specific path
 
 Options:
   -h,--help     Displays Enbld's help.
   -v,--version  Displays Enbld's version.
   -f,--force    Install target whether it is installed or not.
-  -n,--notest   Skip target's test at installtion process. - now default
   -t,--test     Execute target's test at installtion process.
   -c,--curret   Displays target's current installed version at 'freeze' command.
 
@@ -42,7 +41,7 @@ SEE ALSO
 
 To see more detailed help, type below command.
 
- $ enblder readme   # displays perldoc of lib/Enbld.pm
+ $ enblder intro    # displays perldoc of lib/Enbld.pm
  $ enblder tutorial # displays perldoc of lib/Enbld/Tutorial.pm
  $ perldoc enblder  # displays perldoc of bin/enblder
 
