@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw/Enbld::Command/;
 
-use Enbld::Catchme;
+use Try::Lite;
 
 require Enbld::App::Configuration;
 require Enbld::Error;
@@ -24,16 +24,15 @@ sub do {
     my $config = Enbld::App::Configuration->search_config( $target_name );
     my $target = Enbld::Target->new( $target_name, $config );
 
-    my $installed = eval {
-        $target->install;
-    };
-
-	catchme 'Enbld::Error' => sub {
+    my $installed = try {
+        return $target->install;
+    } ( 'Enbld::Error' => sub {
         Enbld::Message->alert( $@ );
         say "\nPlease check build logile:" . Enbld::Logger->logfile;
 
 		return;
-	};
+        }
+      );
 
     if ( $installed ) {
         Enbld::App::Configuration->set_config( $installed );
