@@ -1,6 +1,6 @@
 package Enbld::Target::Attribute::ArchiveName;
 
-use strict;
+use 5.012;
 use warnings;
 
 use Carp;
