@@ -1,6 +1,6 @@
 package Enbld::Definition::Dummy;
 
-use strict;
+use 5.012;
 use warnings;
 
 use parent qw/Enbld::Definition/;
